pub enum StatSplit {
Pitching(Box<PitchingStat>),
Hitting(Box<HittingStat>),
}Expand description
StatSplit stores the two options for deserializing a Split.
It uses the untagged enum representation to determine which one.
https://serde.rs/enum-representations.html#untagged
Variants
Pitching(Box<PitchingStat>)
Hitting(Box<HittingStat>)